==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-runner/translations/razor-runner_cs_CZ.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs_CZ">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Razor-runner Settings</source>
        <translation>Nastavení pro spouštěč programů</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Umístění:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>Ukázat na:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="56"/>
        <source>Shortcut:</source>
        <translation>Klávesová zkratka:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="68"/>
        <source>Top edge of screen</source>
        <translation>Horní okraj obrazovky</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="69"/>
        <source>Center of screen</source>
        <translation>Střed obrazovky</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="75"/>
        <source>Monitor where the mouse</source>
        <translation>Tam, kde je myš</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="80"/>
        <source>Always on %1 monitor</source>
        <translation>Vždy na %1 obrazovce</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Spouštěč programů</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="86"/>
        <source>Configure razor-runner</source>
        <translation>Nastavit razor-runner</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="286"/>
        <source>Press &quot;%1&quot; to see dialog.</source>
        <translation>Stisknětej &quot;%1&quot; pro zobrazení dialogu.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="219"/>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="305"/>
        <source>Mathematics</source>
        <translation>Matematika</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-runner/translations/razor-runner_cs_CZ.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs_CZ" version="2.0">
<context>
    <name>ConfigureDialog</name>
    <message>
        <source>Razor-runner Settings</source>
        <translation>Nastavení spouštěče programů</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <source>Positioning:</source>
        <translation>Umístění:</translation>
    </message>
    <message>
        <source>Show on:</source>
        <translation>Ukázat na:</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Klávesová zkratka:</translation>
    </message>
    <message>
        <source>Top edge of screen</source>
        <translation>Horní okraj obrazovky</translation>
    </message>
    <message>
        <source>Center of screen</source>
        <translation>Střed obrazovky</translation>
    </message>
    <message>
        <source>Monitor where the mouse</source>
        <translation>Tam, kde je myš</translation>
    </message>
    <message>
        <source>Always on %1 monitor</source>
        <translation>Vždy na %1 obrazovce</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Application launcher </source>
        <translation>Spouštěč programů</translation>
    </message>
    <message>
        <source>Configure razor-runner</source>
        <translation>Nastavit spouštěč programů</translation>
    </message>
    <message>
        <source>Clear razor-runner History</source>
        <translation>Smazat historii spouštěče programů</translation>
    </message>
    <message>
        <source>Press &quot;%1&quot; to see dialog.</source>
        <translation>Stiskněte &quot;%1&quot; pro zobrazení dialogu.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <source>Mathematics</source>
        <translation>Matematika</translation>
    </message>
    <message>
        <source>Razor Power Management</source>
        <translation>Správa energie</translation>
    </message>
</context>
</TS>
